@@ -55,12 +55,7 @@ describe 'basic nova' do
       class { '::nova::keystone::authtoken':
         password => 'a_big_secret',
       }
-      # TODO(aschultz): ubuntu's version of these commands are too old. Only
-      # run the cell_v2 on the redhat test until after Ocata-m3 is available
-      # from UCA
-      if $::osfamily == 'RedHat' {
-        include '::nova::cell_v2::simple_setup'
-      }
+      include '::nova::cell_v2::simple_setup'
       class { '::nova::api':
         service_name   => 'httpd',
       }
@@ -68,15 +63,11 @@ describe 'basic nova' do
       class { '::nova::wsgi::apache_api':
         ssl => false,
       }
-      # The Ubuntu package is now broken, it tries to run the app with systemd.
-      # Until it's fixed, let's test it on Red Hat only.
-      if $::osfamily == 'RedHat' {
-        class { '::nova::wsgi::apache_placement':
-          ssl => false,
-        }
-        class { '::nova::placement':
-          password => 'a_big_secret',
-        }
+      class { '::nova::wsgi::apache_placement':
+        ssl => false,
+      }
+      class { '::nova::placement':
+        password => 'a_big_secret',
       }
       class { '::nova::cert': }
       class { '::nova::client': }
